==> synimport-8.x-1.03.tar.gz: synimport/src/Service/CreateEntity.php <==
<?php

namespace Drupal\synimport\Service;

use Symfony\Component\Process\Process;
use Drupal\pathauto\PathautoState;

/**
 * CreateEntity class.
 *
 * @internal
 *   For internal usage by the synimport module.
 */
class CreateEntity implements ImportInterface {
  /**
   * Global logger variable.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $logger;

  /**
   * Service for service.
   *
   * @var Drupal\synimport\Service\FilesImport
   */
  protected $filesImport;

  /**
   * Controller constructor.
   */
  public function __construct(ImportInterface $filesImport) {
    $this->filesImport = $filesImport;
  }

  /**
   * SendMessages to docker.
   */
  private function dockerLogger(string $msg) {
    $timeout = 60000;
    $cmd = "cd ../console/ && ./console.php tpl:echo '$msg'";
    $process = new Process($cmd);
    $process->setTimeout($timeout);
    $process->start();
    $process->wait();
    return [
      'success' => $process->isSuccessful(),
      'output' => $process->getOutput(),
      'error' => $process->getErrorOutput(),
    ];
  }

  /**
   * CreateEntity.
   */
  public function create(array $entity_array, string $storage_name, $parent = NULL) {
    $storage = \Drupal::entityTypeManager()->getStorage($storage_name);
    $result = [
      'uid' => 1,
    ];
    if ($storage_name == 'taxonomy_term') {
      if ($parent != NULL) {
        $result['parent'] = [['target_id' => $parent]];
        $parent_term = $storage->load($parent);
        $result['vid'] = $parent_term->bundle();
      }
      elseif (!empty($entity_array['vocabulary']['vid'])) {
        $result['vid'] = $entity_array['vocabulary']['vid'];
      }
    }
    if ($storage_name == 'commerce_product_variation') {
      $result['sku'] = $parent;
      $result['id'] = $parent;
      $result['type'] = 'variation';
    }
    if ($storage_name == 'commerce_product_attribute_value') {
      $ids = $this->issetAttribute($entity_array, $parent);
      if (!empty($ids)) {
        return $storage->load(array_shift($ids));
      }
      $result['attribute'] = $parent;
    }

    $result = $this->arrayAssembly($entity_array, $result);

    if ($storage_name == 'taxonomy_vocabulary' && empty($vocabulary_array['vname'])) {
      $result['vname'] = $entity_array['vid'];
    }
    $entity = $storage->create($result);
    $entity->save();
    if ($storage_name == 'node' && !empty($entity_array['path'])) {
      $entity->path = [
        'alias' => $entity_array['path'],
        'pathauto' => PathautoState::SKIP,
      ];
    }
    if ($storage_name == 'taxonomy_term' && !empty($entity_array['children_terms'])) {
      foreach ($entity_array['children_terms'] as $child_term) {
        $this->create($child_term, $storage_name, $entity->id());
      }
    }

    $entity_title = $entity->label();
    $entity_id = $entity->id();
    $entity_type_id = $entity->getEntityTypeId();
    $this->dockerLogger("$entity_type_id: $entity_title" . "[$entity_id]");
    return $entity;
  }

  /**
   * PreparesArray.
   */
  private function arrayAssembly(array $entity_array, array $result) {
    foreach ($entity_array as $key => $value) {
      if (!empty($value['type'])) {
        switch ($value['type']) {
          case 'image':
            $result[$key] = $this->filesImport->importImages($value['content']);
            break;

          case 'attach':
            $result[$key] = $this->filesImport->importAttach($value['content']);
            break;

          case 'media':
            $result[$key] = $this->filesImport->importMedia($value['content']);
            break;

          case 'taxonomy':
            $result[$key] = $this->importTaxonomyField($value['content']);
            break;

          case 'paragraph':
            $paragraphs = [];
            foreach ($value['content'] as $paragraphs_array) {
              $paragraph = $this->create($paragraphs_array, 'paragraph');
              $paragraphs[] = [
                'target_id' => $paragraph->id(),
                'target_revision_id' => $paragraph->getRevisionId(),
              ];
            }
            $result[$key] = $paragraphs;
            break;

          case 'variations':
            $variations = [];
            foreach ($value['content'] as $key1 => $value1) {
              $variation = $this->create($value1, 'commerce_product_variation', $key1);
              $variations[] = $variation->id();
            }
            $result[$key] = $variations;
            break;

          case 'attribute':
            $result["attribute_$key"] = $this->create($value['content'], 'commerce_product_attribute_value', $key);
            break;

          case 'price':
            $result['price'] = [
              'number' => (int) filter_var($value['content']['price'], FILTER_SANITIZE_NUMBER_INT),
              'currency_code' => $value['content']['currency'],
            ];
            break;

          default:
            $result[$key] = $value['content'];
            break;
        }
      }
      else {
        $result[$key] = $value;
      }
    }
    return $result;
  }

  /**
   * Import TaxonomyField by name or name and vocabulary.
   */
  private function importTaxonomyField($term_name) {
    if (!empty($term_name)) {
      $term_id = $this->getTidByName($term_name);
      return $term_id;
    }
  }

  /**
   * Get taxonomy term id by name or by name and vocabulary id.
   */
  private function getTidByName($name = NULL, $vid = NULL) {
    $properties = [];
    if (!empty($name)) {
      $properties['name'] = $name;
    }
    if (!empty($vid)) {
      $properties['vid'] = $vid;
    }
    $terms = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadByProperties($properties);
    $term = reset($terms);
    return !empty($term) ? $term->id() : 0;
  }

  /**
   * Check already created attributes.
   */
  private function issetAttribute(array $attribute_array, string $name) {
    $query = \Drupal::entityQuery('commerce_product_attribute_value');
    if ($name == 'color') {
      $query->condition('field_hex', $attribute_array['field_hex']);
    }
    else {
      $query->condition('name', $attribute_array['name']);
    }
    return $query->execute();
  }

}

==> synimport-8.x-1.51.tar.gz: synimport/src/Service/CreateEntity.php <==
<?php

namespace Drupal\synimport\Service;

use Drupal\pathauto\PathautoState;
use Drupal\synimport\Classes\Logger;

/**
 * CreateEntity class.
 *
 * @internal
 *   For internal usage by the synimport module.
 */
class CreateEntity implements ImportInterface {
  /**
   * Service for service.
   *
   * @var Drupal\synimport\Service\FilesImport
   */
  protected $filesImport;

  /**
   * Controller constructor.
   */
  public function __construct(ImportInterface $filesImport) {
    $this->filesImport = $filesImport;
    $this->logger = new Logger();
  }

  /**
   * CreateEntity.
   */
  public function create(array $entity_array, string $storage_name, $parent = NULL) {
    $storage = \Drupal::entityTypeManager()->getStorage($storage_name);
    $result = [
      'uid' => 1,
    ];
    if ($storage_name == 'taxonomy_term') {
      if ($parent != NULL) {
        $result['parent'] = [['target_id' => $parent]];
        $parent_term = $storage->load($parent);
        $result['vid'] = $parent_term->bundle();
      }
      elseif (!empty($entity_array['vocabulary']['vid'])) {
        $result['vid'] = $entity_array['vocabulary']['vid'];
      }
    }
    if ($storage_name == 'commerce_product_variation') {
      $result['sku'] = $parent;
      $result['id'] = $parent;
      $result['type'] = 'variation';
    }
    if ($storage_name == 'commerce_product_attribute_value') {
      $ids = $this->issetAttribute($entity_array, $parent);
      if (!empty($ids)) {
        return $storage->load(array_shift($ids));
      }
      $result['attribute'] = $parent;
    }

    $result = $this->arrayAssembly($entity_array, $result);

    if ($storage_name == 'taxonomy_vocabulary' && empty($vocabulary_array['vname'])) {
      $result['vname'] = $entity_array['vid'];
    }
    $entity = $storage->create($result);
    $entity->save();
    if ($storage_name == 'node' && !empty($entity_array['path'])) {
      $entity->path = [
        'alias' => $entity_array['path'],
        'pathauto' => PathautoState::SKIP,
      ];
    }
    if ($storage_name == 'taxonomy_term' && !empty($entity_array['children_terms'])) {
      foreach ($entity_array['children_terms'] as $child_term) {
        $this->create($child_term, $storage_name, $entity->id());
      }
    }

    $entity_title = $entity->label();
    $entity_id = $entity->id();
    $entity_type_id = $entity->getEntityTypeId();
    $this->logger->notice("$entity_type_id: $entity_title" . "[$entity_id]");
    return $entity;
  }

  /**
   * PreparesArray.
   */
  private function arrayAssembly(array $entity_array, array $result) {
    foreach ($entity_array as $key => $value) {
      if (!empty($value['type'])) {
        switch ($value['type']) {
          case 'image':
            $result[$key] = $this->filesImport->importImages($value['content']);
            break;

          case 'attach':
            $result[$key] = $this->filesImport->importAttach($value['content']);
            break;

          case 'media':
            $result[$key] = $this->filesImport->importMedia($value['content']);
            break;

          case 'taxonomy':
            $result[$key] = $this->importTaxonomyField($value['content']);
            break;

          case 'paragraph':
            $paragraphs = [];
            foreach ($value['content'] as $paragraphs_array) {
              $paragraph = $this->create($paragraphs_array, 'paragraph');
              $paragraphs[] = [
                'target_id' => $paragraph->id(),
                'target_revision_id' => $paragraph->getRevisionId(),
              ];
            }
            $result[$key] = $paragraphs;
            break;

          case 'variations':
            $variations = [];
            foreach ($value['content'] as $key1 => $value1) {
              $variation = $this->create($value1, 'commerce_product_variation', $key1);
              $variations[] = $variation->id();
            }
            $result[$key] = $variations;
            break;

          case 'attribute':
            $result["attribute_$key"] = $this->create($value['content'], 'commerce_product_attribute_value', $key);
            break;

          case 'price':
            $result['price'] = [
              'number' => (int) filter_var($value['content']['price'], FILTER_SANITIZE_NUMBER_INT),
              'currency_code' => $value['content']['currency'],
            ];
            break;

          default:
            $result[$key] = $value['content'];
            break;
        }
      }
      else {
        $result[$key] = $value;
      }
    }
    return $result;
  }

  /**
   * Import TaxonomyField by name or name and vocabulary.
   */
  private function importTaxonomyField($term_name) {
    if (!empty($term_name)) {
      $term_id = $this->getTidByName($term_name);
      return $term_id;
    }
  }

  /**
   * Get taxonomy term id by name or by name and vocabulary id.
   */
  private function getTidByName($name = NULL, $vid = NULL) {
    $properties = [];
    if (!empty($name)) {
      $properties['name'] = $name;
    }
    if (!empty($vid)) {
      $properties['vid'] = $vid;
    }
    $terms = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadByProperties($properties);
    $term = reset($terms);
    return !empty($term) ? $term->id() : 0;
  }

  /**
   * Check already created attributes.
   */
  private function issetAttribute(array $attribute_array, string $name) {
    $query = \Drupal::entityQuery('commerce_product_attribute_value');
    if ($name == 'color') {
      $query->condition('field_hex', $attribute_array['field_hex']);
    }
    else {
      $query->condition('name', $attribute_array['name']);
    }
    return $query->execute();
  }

}
